/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Pierre Phaneuf <pp@ludusdesign.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIModule.h"
#include "nsIGenericFactory.h"
#include "nsJVMAuthTools.h"
#include "nsJVMManager.h"
#include "nsJVMConfigManager.h"

#ifdef XP_UNIX
#include "nsJVMConfigManagerUnix.h"
#endif

/*
 * Note:  In revision 1.17 of this file (and earlier) there was a
 * commented out implementation of nsCJVMManagerFactory, a hand-crafted
 * implementation of nsIFactory.
 */
#ifdef XP_UNIX
NS_GENERIC_FACTORY_CONSTRUCTOR(nsJVMConfigManagerUnix)
#endif

// The list of components we register
static const nsModuleComponentInfo components[] = 
{
    { "JVM Manager Service", 
      NS_JVMMANAGER_CID,  
      "@mozilla.org/oji/jvm-mgr;1", 
      nsJVMManager::Create
    },

    { "JVM Authentication Service", 
      NS_JVMAUTHTOOLS_CID,  
      "@mozilla.org/oji/jvm-auth-tools;1", 
      nsJVMAuthTools::Create
    },
#ifdef XP_UNIX
    { "JVM Config Manager",
      NS_JVMCONFIGMANAGER_CID,
      "@mozilla.org/oji/jvm-config-mgr;1",
      nsJVMConfigManagerUnixConstructor
    },
#endif
};

NS_IMPL_NSGETMODULE(nsCJVMManagerModule, components)
