@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

.wizard-header {
  border-bottom: 2px groove ThreeDFace;
  padding: 10px 0px 10px 0px;
  background-color: Window;
  color: WindowText;
}

.wizard-header-label {
  margin-left: 23px;
  font-weight: bold;
}

.wizard-header-description {
  margin-left: 44px;
}

.wizard-page-box {
  margin: 10px 44px;
}

.wizard-buttons-separator {
  margin-bottom: 0px !important;
}

.wizard-buttons-box-2 {
  margin: 10px;
}

.wizard-button[wizardbutton="finish"],
.wizard-button[wizardbutton="next"] {
  margin-left: -1px !important;
}

.wizard-button[wizardbutton="back"] {
  margin-right: 0px !important;
}
